@@ -1,6 +1,6 @@
 package Gearman::Worker;
 use version;
-$Gearman::Worker::VERSION = version->declare("2.004.008");
+$Gearman::Worker::VERSION = version->declare("2.004.009");
 
 use strict;
 use warnings;
@@ -118,6 +118,7 @@ use Carp          ();
 use Gearman::Util ();
 use Gearman::Job;
 use Storable ();
+use IO::Select;
 
 use fields (
     'last_connect_fail',    # host:port -> unixtime
@@ -220,9 +221,6 @@ sub work {
     # in the loop we contact all servers.
     my %active_js = map { $_ => 1 } keys(%js_map);
 
-    # ( js => last_update_time, ... )
-    my %last_update_time;
-
     while (1) {
 
         # "Jobby" job servers are the set of server which we will contact
@@ -239,7 +237,7 @@ sub work {
             my $js_index = ($i + $js_offset) % $js_count;
             my $js_str   = $jobby_js[$js_index];
             my $js       = $js_map{$js_str};
-            my $jss      = $self->_get_js_sock($js, on_connect => $on_connect)
+            my $jss      = $self->_get_js_sock($js, on_connect => $on_connect, register_on_reconnect => 1)
                 or next;
 
             # TODO: add an optional sleep in here for the test suite
@@ -255,7 +253,6 @@ sub work {
                 } ## end if ($!{EPIPE} && $self...)
 
                 $self->_uncache_sock($js, "grab_job_timeout");
-                delete $last_update_time{$js_str};
                 next;
             } ## end unless (_send($jss, \$grab_req...))
 
@@ -267,7 +264,6 @@ sub work {
             unless (Gearman::Util::wait_for_readability($jss->fileno, $timeout))
             {
                 $self->_uncache_sock($js, "grab_job_timeout");
-                delete $last_update_time{$js_str};
                 next;
             } ## end unless (Gearman::Util::wait_for_readability...)
 
@@ -277,17 +273,14 @@ sub work {
                 $res = Gearman::Util::read_res_packet($jss, \$err);
                 unless ($res) {
                     $self->_uncache_sock($js, "read_res_error");
-                    delete $last_update_time{$js_str};
                     next;
                 }
             } while ($res->{type} eq "noop");
 
             if ($res->{type} eq "no_job") {
                 unless (_send($jss, \$presleep_req)) {
-                    delete $last_update_time{$js_str};
                     $self->_uncache_sock($js, "write_presleep_error");
                 }
-                $last_update_time{$js_str} = time;
                 next;
             } ## end if ($res->{type} eq "no_job")
 
@@ -320,7 +313,8 @@ sub work {
             my $err     = $@;
             warn "Job '$ability' died: $err" if $err;
 
-            $last_update_time{$js_str} = $last_job_time = time();
+            $last_job_time = time();
+
             if ($err) {
                 my $exception_req
                     = _rc("work_exception",
@@ -352,53 +346,29 @@ sub work {
                 $self->_uncache_sock($js, "write_res_error");
                 next;
             }
-
-            $active_js{$js_str} = 1;
         } ## end for (my $i = 0; $i < $js_count...)
 
-        my @jss;
-
         foreach my $js_str (keys(%js_map)) {
             my $jss
                 = $self->_get_js_sock($js_map{$js_str},
-                on_connect => $on_connect)
-                or next;
-            push @jss, [$js_str, $jss];
+                on_connect => $on_connect, register_on_reconnect => 1);
+              $jss || next;
+
+            my $io = IO::Select->new($jss);
+            $io->can_write(10) || next;
+
+            if($last_job_time && time() - $last_job_time >= 10) {
+                # chill for some arbitrary time until we're woken up again
+                select($io->bits(), undef, undef, 10 + rand(2));
+            }
+
+            $active_js{$js_str} = 1;
         } ## end foreach my $js_str (keys(%js_map...))
 
-        my $wake_vec = '';
-
-        foreach my $j (@jss) {
-            (undef, my $_jss) = @{$j};
-            my $fd = $_jss->fileno;
-            vec($wake_vec, $fd, 1) = 1;
-        }
-
-        my $timeout = keys(%active_js) ? 0 : (10 + rand(2));
-
-        # chill for some arbitrary time until we're woken up again
-        my $nready = select(my $wout = $wake_vec, undef, undef, $timeout);
-
-        if ($nready) {
-            foreach my $j (@jss) {
-                my ($js_str, $jss) = @{$j};
-                my $fd = $jss->fileno;
-                $active_js{$js_str} = 1
-                    if vec($wout, $fd, 1);
-            } ## end foreach my $j (@jss)
-        } ## end if ($nready)
-
         my $is_idle = scalar(keys %active_js) > 0 ? 0 : 1;
 
-        return if $stop_if->($is_idle, $last_job_time);
-
-        my $update_since = time - (15 + rand 60);
-
-        while (my ($js_str, $last_update) = each %last_update_time) {
-            $active_js{$js_str} = 1 if $last_update < $update_since;
-        }
+        last if $stop_if->($is_idle, $last_job_time);
     } ## end while (1)
-
 } ## end sub work
 
 =head2 $worker->register_function($funcname, $subref)
@@ -519,10 +489,12 @@ sub send_work_warning {
     return $self->_job_request("work_warning", $job, $msg);
 }
 
-=head4 send_work_exception($job, $exception)
+=head2 send_work_exception($job, $exception)
 
 Use this method to notify the server (and any listening clients) that the C<job> failed with the given C<$exception>.
 
+If you are using L<Gearman::Client>, you have to set parameter exceptions properly to get worker exception notifications.
+
 =cut
 
 sub send_work_exception {
@@ -628,9 +600,9 @@ sub _get_js_sock {
     my $now        = time;
     my $down_since = $self->{down_since}{$js_str};
     if ($down_since) {
-        warn "$js_str down since $down_since" if $self->debug;
-
         my $down_for = $now - $down_since;
+        warn "$js_str down for $down_for" if $self->debug;
+
         my $retry_period = $down_for > 60 ? 30 : (int($down_for / 2) + 1);
         if ($self->{last_connect_fail}{$js_str} > $now - $retry_period) {
             return;
@@ -650,13 +622,12 @@ sub _get_js_sock {
     $sock->autoflush(1);
     $self->sock_nodelay($sock);
 
-    $self->_sock_cache($js, $sock);
-
     delete $self->{last_connect_fail}{$js_str};
-    if (delete $self->{down_since}{$js_str}) {
-        my @can  = keys %{ $self->{can} };
+    delete $self->{down_since}{$js_str};
+
+    if( $opts{register_on_reconnect} ) {
         my @fail = ();
-        foreach (@can) {
+        foreach (keys %{ $self->{can} }) {
             $self->_register_function($_, $js, $sock) || push @fail, $_;
         }
 
@@ -667,6 +638,8 @@ sub _get_js_sock {
         }
     } ## end if (delete $self->{down_since...})
 
+    $self->_sock_cache($js, $sock);
+
     if ($on_connect && !$on_connect->($sock)) {
         $self->_uncache_sock($js, "on connect callback failed");
         return;
